==> jc-1.4.0.tar.gz: soot/relations/JBuddyProfiler__24Event.h <==
// class soot.relations.JBuddyProfiler$Event

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 28ccee6efba6e79 soot_relations_JBuddyProfiler__24Event

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler__24Event_H_
#define _JC_soot_relations_JBuddyProfiler__24Event_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Date$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$sub_refs	_jc_soot_relations_JBuddyProfiler__24Event$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs	_jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$refs	_jc_soot_relations_JBuddyProfiler__24Event$refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$nonrefs	_jc_soot_relations_JBuddyProfiler__24Event$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$object	_jc_soot_relations_JBuddyProfiler__24Event$object;

typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vmethods	_jc_soot_relations_JBuddyProfiler__24Event$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vtable	_jc_soot_relations_JBuddyProfiler__24Event$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vtype	_jc_soot_relations_JBuddyProfiler__24Event$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler__24Event$method$_init$15d18cf46af92b1d(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Event$object *, struct _jc_soot_relations_JBuddyProfiler$object *);

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler__24Event$vmethods {
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler__24Event$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler__24Event$vmethods	soot_relations_JBuddyProfiler__24Event;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler__24Event$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler__24Event$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Event$sub_refs {
	struct _jc_java_util_Date$object	*startTime;
	struct _jc_soot_relations_JBuddyProfiler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Event$refs {
    _jc_soot_relations_JBuddyProfiler__24Event$sub_refs	soot_relations_JBuddyProfiler__24Event;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs {
	jint	bdd1;
	jint	bdd2;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Event$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs	soot_relations_JBuddyProfiler__24Event;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler__24Event$object {
	_jc_soot_relations_JBuddyProfiler__24Event$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler__24Event$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler__24Event$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler__24Event$vtype _jc_soot_relations_JBuddyProfiler__24Event$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler__24Event, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler__24Event$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler__24Event_H_ */

==> jc-1.4.6.tar.gz: soot/relations/JBuddyProfiler__24Event.h <==
// class soot.relations.JBuddyProfiler$Event

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 28ccee6efba6e79 soot_relations_JBuddyProfiler__24Event

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler__24Event_H_
#define _JC_soot_relations_JBuddyProfiler__24Event_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Date$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$sub_refs	_jc_soot_relations_JBuddyProfiler__24Event$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs	_jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$refs	_jc_soot_relations_JBuddyProfiler__24Event$refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$nonrefs	_jc_soot_relations_JBuddyProfiler__24Event$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Event$object	_jc_soot_relations_JBuddyProfiler__24Event$object;

typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vmethods	_jc_soot_relations_JBuddyProfiler__24Event$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vtable	_jc_soot_relations_JBuddyProfiler__24Event$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Event$vtype	_jc_soot_relations_JBuddyProfiler__24Event$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler__24Event$method$_init$15d18cf46af92b1d(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Event$object *, struct _jc_soot_relations_JBuddyProfiler$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler__24Event$vmethods {
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler__24Event$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler__24Event$vmethods	soot_relations_JBuddyProfiler__24Event;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler__24Event$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler__24Event$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Event$sub_refs {
	struct _jc_java_util_Date$object	*startTime;
	struct _jc_soot_relations_JBuddyProfiler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Event$refs {
    _jc_soot_relations_JBuddyProfiler__24Event$sub_refs	soot_relations_JBuddyProfiler__24Event;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs {
	jint	bdd1;
	jint	bdd2;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Event$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler__24Event$sub_nonrefs	soot_relations_JBuddyProfiler__24Event;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler__24Event$object {
	_jc_soot_relations_JBuddyProfiler__24Event$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler__24Event$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler__24Event$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler__24Event$vtype _jc_soot_relations_JBuddyProfiler__24Event$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler__24Event, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler__24Event$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler__24Event_H_ */
